summaryrefslogtreecommitdiff
path: root/girepository/gibaseinfo.c
diff options
context:
space:
mode:
authorJohan Dahlin <johan@gnome.org>2010-08-31 17:36:06 -0300
committerJohan Dahlin <johan@gnome.org>2010-08-31 17:37:10 -0300
commit7af39d0ff23d5a8c2316536b864f576f9a2bebc6 (patch)
tree6b10e6277ed3f9f8f24d458f88030b14f5101da4 /girepository/gibaseinfo.c
parent6379b8a497e2bf8c5b09e37ded88c7a28483389d (diff)
downloadgobject-introspection-7af39d0ff23d5a8c2316536b864f576f9a2bebc6.tar.gz
[GIRepository] Rename GTypelib to GITypelib
Keep a typedef for backwards compatibility, until the major bindings has moved over.
Diffstat (limited to 'girepository/gibaseinfo.c')
-rw-r--r--girepository/gibaseinfo.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/girepository/gibaseinfo.c b/girepository/gibaseinfo.c
index 81b936d8..a4c9f90b 100644
--- a/girepository/gibaseinfo.c
+++ b/girepository/gibaseinfo.c
@@ -35,7 +35,7 @@ GIBaseInfo *
_g_info_new_full (GIInfoType type,
GIRepository *repository,
GIBaseInfo *container,
- GTypelib *typelib,
+ GITypelib *typelib,
guint32 offset)
{
GIRealInfo *info;
@@ -58,7 +58,7 @@ _g_info_new_full (GIInfoType type,
GIBaseInfo *
g_info_new (GIInfoType type,
GIBaseInfo *container,
- GTypelib *typelib,
+ GITypelib *typelib,
guint32 offset)
{
return _g_info_new_full (type, ((GIRealInfo*)container)->repository, container, typelib, offset);
@@ -69,7 +69,7 @@ _g_info_init (GIRealInfo *info,
GIInfoType type,
GIRepository *repository,
GIBaseInfo *container,
- GTypelib *typelib,
+ GITypelib *typelib,
guint32 offset)
{
memset (info, 0, sizeof (GIRealInfo));
@@ -90,7 +90,7 @@ _g_info_init (GIRealInfo *info,
GIBaseInfo *
_g_info_from_entry (GIRepository *repository,
- GTypelib *typelib,
+ GITypelib *typelib,
guint16 index)
{
GIBaseInfo *result;
@@ -127,7 +127,7 @@ _g_info_from_entry (GIRepository *repository,
GITypeInfo *
_g_type_info_new (GIBaseInfo *container,
- GTypelib *typelib,
+ GITypelib *typelib,
guint32 offset)
{
SimpleTypeBlob *type = (SimpleTypeBlob *)&typelib->data[offset];
@@ -139,7 +139,7 @@ _g_type_info_new (GIBaseInfo *container,
void
_g_type_info_init (GIBaseInfo *info,
GIBaseInfo *container,
- GTypelib *typelib,
+ GITypelib *typelib,
guint32 offset)
{
GIRealInfo *rinfo = (GIRealInfo*)container;
@@ -153,7 +153,7 @@ _g_type_info_init (GIBaseInfo *info,
/**
* SECTION:gibaseinfo
* @Short_description: Base struct for all GTypelib structs
* @Title: GIBaseInfo
*
* GIBaseInfo is the common base struct of all other *Info structs
@@ -611,7 +611,7 @@ g_base_info_get_container (GIBaseInfo *info)
*
* Returns: (transfer none): the typelib.
*/
-GTypelib *
+GITypelib *
g_base_info_get_typelib (GIBaseInfo *info)
{
return ((GIRealInfo*)info)->typelib;
@@ -153,7 +153,7 @@ _g_type_info_init (GIBaseInfo *info,
/**
* SECTION:gibaseinfo
- * @Short_description: Base struct for all GTypelib structs
+ * @Short_description: Base struct for all GITypelib structs
* @Title: GIBaseInfo
*